pub enum OwnerPetRelationship {
Resolved,
Ambiguous {
candidate_count: u16,
},
}Expand description
Confidence in the provider relationship between an owner and pet.
Variants
Resolved
Owner-pet relationship was matched to a single confident record.
Ambiguous
Number of provider records that could match this relationship.