pub struct Snapshot { /* private fields */ }Expand description
Point-in-time source-data view used before promotion into core domain records.
Implementations
Sourceimpl Snapshot
impl Snapshot
Sourcepub const fn builder() -> SnapshotBuilder
pub const fn builder() -> SnapshotBuilder
Returns the builder evidence carried by this source-lineage value.
Sourcepub const fn provenance(&self) -> &Provenance
pub const fn provenance(&self) -> &Provenance
Returns the provenance evidence carried by this source-lineage value.
Sourcepub const fn customer_record_id(&self) -> Option<&Id>
pub const fn customer_record_id(&self) -> Option<&Id>
Returns the customer record id evidence carried by this source-lineage value.
Sourcepub const fn pet_record_id(&self) -> Option<&Id>
pub const fn pet_record_id(&self) -> Option<&Id>
Returns the pet record id evidence carried by this source-lineage value.
Sourcepub const fn location_record_id(&self) -> Option<&Id>
pub const fn location_record_id(&self) -> Option<&Id>
Returns the location record id evidence carried by this source-lineage value.
Sourcepub const fn service_type_record_id(&self) -> Option<&Id>
pub const fn service_type_record_id(&self) -> Option<&Id>
Returns the service type record id evidence carried by this source-lineage value.
Sourcepub fn status(&self) -> Option<Status>
pub fn status(&self) -> Option<Status>
Returns the status evidence carried by this source snapshot.
Sourcepub const fn relationship(&self) -> &OwnerPetRelationship
pub const fn relationship(&self) -> &OwnerPetRelationship
Returns the relationship evidence carried by this source-lineage value.
Sourcepub fn assumptions(&self) -> &[Assumption]
pub fn assumptions(&self) -> &[Assumption]
Returns the assumptions evidence carried by this source snapshot.
Sourcepub fn data_quality_issues(&self, detected_at: Timestamp) -> Vec<Issue>
pub fn data_quality_issues(&self, detected_at: Timestamp) -> Vec<Issue>
Returns the data quality issues evidence carried by this source snapshot.